==> Yuoki_0.5.70.zip: Yuoki_0.5.70/prototypes/item/ir_atomics.lua <==
data:extend(
{
	-- pure atomic constructs
	{
		type = "recipe",
		name = "y-ac-iron2uc-recipe", order="a",
		energy_required = 2.0,
		enabled = "true",
		ingredients = {{"iron-ore", 20},}, 
		result = "y-unicomp-a2",
		result_count = 1,
		subgroup = "y-atomics-f", 
		category = "yuoki-atomics-recipe",
		icon = "__Yuoki__/graphics/icons/atomics/iron2uc.png",
	},		
	{
		type = "recipe",
		name = "y-ac-copper2uc-recipe", order="a",	
		energy_required = 2.0,
		enabled = "true",
		ingredients = {{"copper-ore", 20},}, 
		result = "y-unicomp-a2",
		result_count = 1,
		subgroup = "y-atomics-f",
		category = "yuoki-atomics-recipe",
		icon = "__Yuoki__/graphics/icons/atomics/copper2uc.png",
	},		
	{
		type = "recipe",
		name = "y-ac-wood2uc-recipe", order="a",
		energy_required = 2.0,
		enabled = "true",
		ingredients = {{"raw-wood", 20},}, 
		result = "y-unicomp-a2",
		result_count = 1,
		subgroup = "y-atomics-f",
		category = "yuoki-atomics-recipe",
		icon = "__Yuoki__/graphics/icons/atomics/wood2uc.png",
	},		
	{
		type = "recipe",
		name = "y-ac-stone2uc-recipe", order="a",
		energy_required = 2.0,
		enabled = "true",
		ingredients = {{"stone", 20},}, 
		result = "y-unicomp-a2",
		result_count = 1,
		subgroup = "y-atomics-f",
		category = "yuoki-atomics-recipe",
		icon = "__Yuoki__/graphics/icons/atomics/stone2uc.png",
	},		
	{
		type = "recipe",
		name = "y-ac-coal2uc-recipe", order="a",
		energy_required = 2.0,
		enabled = "true",
		ingredients = {{"coal", 20},}, 
		result = "y-unicomp-a2",
		result_count = 1,
		subgroup = "y-atomics-f",
		category = "yuoki-atomics-recipe",
		icon = "__Yuoki__/graphics/icons/atomics/coal2uc.png",
	},		
	{
		type = "recipe",
		name = "y-ac-uc42uc-recipe", order="a",
		energy_required = 2.0,
		enabled = "true",
		ingredients = {{"y-res1", 10},}, 
		result = "y-unicomp-a2",
		result_count = 1,
		subgroup = "y-atomics-f",
		category = "yuoki-atomics-recipe",
		icon = "__Yuoki__/graphics/icons/atomics/n42uc.png",
	},			
	{
		type = "recipe",
		name = "y-ac-fuel2uc-recipe", order="a",
		energy_required = 2.0,
		enabled = "true",
		ingredients = {{"y-res2", 10},}, 
		result = "y-unicomp-a2",
		result_count = 1,
		subgroup = "y-atomics-f",
		category = "yuoki-atomics-recipe",
		icon = "__Yuoki__/graphics/icons/atomics/fuel2uc.png",
	},		
	{
		type = "recipe",
		name = "y-ac-slag2uc-recipe", order="a",
		energy_required = 2.0,
		enabled = "true",
		ingredients = {{"y-slag", 100},}, 
		result = "y-unicomp-a2",
		result_count = 1,
		subgroup = "y-atomics-f",
		category = "yuoki-atomics-recipe",
		icon = "__Yuoki__/graphics/icons/atomics/slag2uc.png",
	},		
	{
		type = "recipe",
		name = "y-ac-crystal2uc-recipe", order="a",
		energy_required = 2.0,
		enabled = "true",
		ingredients = {{"y-crystal2", 100},}, 
		result = "y-unicomp-a2",
		result_count = 1,
		subgroup = "y-atomics-f",
		category = "yuoki-atomics-recipe",
		icon = "__Yuoki__/graphics/icons/atomics/crystal2uc.png",
	},			
	
	--[[
	{
		type = "recipe",
		name = "y-battery-rip1-recipe",				
		energy_required = 1.0,
		enabled = "true",
		ingredients = {{"y-battery-single-use1", 10},}, 
		result = "y-unicomp-a2",
		result_count = 1,
		category = "yuoki-atomics-recipe",
		subgroup = "y-atomics-f",
	},	
	{
		type = "recipe",
		name = "y-battery-rip2-recipe",				
		energy_required = 1.0,
		enabled = "true",
		ingredients = {{"y-unicomp-a2", 1},}, 
		result = "battery",
		result_count = 5,
		category = "yuoki-atomics-recipe",
		subgroup = "y-atomics-r",
	},	
	{
		type = "recipe",
		name = "y_alien_artis2_recipe",				
		energy_required = 1.0,
		enabled = "true",
		ingredients = {{"y-unicomp-a2", 1},}, 
		result = "alien-artifact",
		result_count = 3,
		category = "yuoki-atomics-recipe",
		subgroup = "y-atomics-r",
	},	

	
	
	
	{
		type = "recipe",
		name = "y_alien_artis1_recipe",				
		energy_required = 1.0,
		enabled = "true",
		ingredients = {{"alien-artifact", 3},}, 
		result = "y-unicomp-a2",
		result_count = 1,
		category = "yuoki-atomics-recipe",
		subgroup = "y-atomics-f",
	},	
	
	]]
	
	
	-- changed to formpress 214-1226 and to smelts 215-0103
	--[[
	{
		type = "recipe",
		name = "y-ac-richdust2uc-recipe", order="a",
		energy_required = 2.0,
		enabled = "true",
		ingredients = {{"y-richdust", 20},}, 
		result = "y-unicomp-a2",
		result_count = 1,
		subgroup = "y-ore",
		category = "yuoki-formpress-recipe",	
		--category = "yuoki-atomics-recipe",
		icon = "__Yuoki__/graphics/icons/richdust.png",
	},
	]]

	-- toxic-dust-recycle
	{
		type = "recipe",
		name = "y-ac-toxic2uc-recipe", order="a",
		energy_required = 2.0,
		enabled = "true",
		ingredients = {{"y-toxic-dust", 70},}, 
		result = "y-unicomp-a2",
		result_count = 1,
		subgroup = "y-atomics-f",
		category = "yuoki-atomics-recipe",
		icon = "__Yuoki__/graphics/icons/toxic-dust_recycle.png",
	},		
	-- mud-ball-recycle
	{
		type = "recipe",
		name = "y-ac-mud2uc-recipe", order="a",
		energy_required = 2.0,
		enabled = "true",
		ingredients = {{"y-dry_mud", 30},}, 
		result = "y-unicomp-a2",
		result_count = 1,
		subgroup = "y-atomics-f",
		category = "yuoki-atomics-recipe",
		icon = "__Yuoki__/graphics/icons/mud_recycle.png",
	},		
	
	
	-- reverse atomic transfers and ++
	{
		type = "recipe",
		name = "y-ac-uc2copper-recipe", order="b",
		energy_required = 2.0,
		enabled = "true",
		ingredients = {{"y-unicomp-a2", 1},}, 
		result = "copper-ore",
		result_count = 20,
		subgroup = "y-atomics-r",
		category = "yuoki-atomics-recipe",
		icon = "__Yuoki__/graphics/icons/atomics/uc2copper.png",
	},		
	{
		type = "recipe",
		name = "y-ac-uc2iron-recipe", order="b",
		energy_required = 2.0,
		enabled = "true",
		ingredients = {{"y-unicomp-a2", 1},}, 
		result = "iron-ore",
		result_count = 20,
		subgroup = "y-atomics-r",
		category = "yuoki-atomics-recipe",
		icon = "__Yuoki__/graphics/icons/atomics/uc2iron.png",
	},		
	{
		type = "recipe",
		name = "y-ac-uc2wood-recipe", order="a",
		energy_required = 2.0,
		enabled = "true",
		ingredients = {{"y-unicomp-a2", 1},}, 
		result = "raw-wood",
		result_count = 20,
		subgroup = "y-atomics-r",
		category = "yuoki-atomics-recipe",
		icon = "__Yuoki__/graphics/icons/atomics/uc2wood.png",
	},		
	{
		type = "recipe",
		name = "y-ac-uc2coal-recipe", order="b",
		energy_required = 2.0,
		enabled = "true",
		ingredients = {{"y-unicomp-a2", 1},}, 
		result = "coal",
		result_count = 20,
		subgroup = "y-atomics-r",
		category = "yuoki-atomics-recipe",
		icon = "__Yuoki__/graphics/icons/atomics/uc2coal.png",
	},		
	{
		type = "recipe",
		name = "y-ac-uc2stone-recipe", order="b",
		energy_required = 2.0,
		enabled = "true",
		ingredients = {{"y-unicomp-a2", 1},}, 
		result = "stone",
		result_count = 20,
		subgroup = "y-atomics-r",
		category = "yuoki-atomics-recipe",
		icon = "__Yuoki__/graphics/icons/atomics/uc2stone.png",
	},		
	{
		type = "recipe",
		name = "y-ac-uc2uc4-recipe", order="b",
		energy_required = 2.0,
		enabled = "true",
		ingredients = {{"y-unicomp-a2", 1},}, 
		result = "y-res1",
		result_count = 10,
		subgroup = "y-atomics-r",
		category = "yuoki-atomics-recipe",
		icon = "__Yuoki__/graphics/icons/atomics/uc2n4.png",
	},		
	{
		type = "recipe",
		name = "y-ac-uc2fuel-recipe", order="b",
		energy_required = 2.0,
		enabled = "true",
		ingredients = {{"y-unicomp-a2", 1},}, 
		result = "y-res2",
		result_count = 10,
		subgroup = "y-atomics-r",
		category = "yuoki-atomics-recipe",
		icon = "__Yuoki__/graphics/icons/atomics/uc2fuel.png",
	},		

	{
		type = "recipe",
		name = "y-ac-uc2plastic-recipe", order="b",
		energy_required = 2.0,
		enabled = "true",
		ingredients = {{"y-unicomp-a2", 1},}, 
		result = "plastic-bar",
		result_count = 8,
		subgroup = "y-atomics-r",
		category = "yuoki-atomics-recipe",
		icon = "__Yuoki__/graphics/icons/atomics/uc2plastic.png",
	},		
	
	--[[
	{
		type = "recipe",
		name = "y-ac-uc2sulfur-recipe", order="b",
		energy_required = 2.0,
		enabled = "true",
		ingredients = {{"y-unicomp-a2", 1},}, 
		result = "sulfur",
		result_count = 6,
		subgroup = "y-atomics-r",
		category = "yuoki-atomics-recipe",
		--icon = "__Yuoki__/graphics/icons/atomics/uc2plastic.png",
	},		
	]]
	
	-- fluid transition
	{
		type = "recipe",		
		name = "y-lightoil2uc-recipe", order="c",
		energy_required = 5,
		ingredients = {
			{type="fluid", name="light-oil", amount=100, }
		},
		results=
		{
			{"y-unicomp-a2", 1},	
		},
		enabled = "true",		
		icon = "__Yuoki__/graphics/icons/atomics/lightoil2uc.png",
		order = "m-refined-rare3",
		subgroup = "y-atomics-f",
		category = "yuoki-atomics-recipe",
	},
	{
		type = "recipe",		
		name = "y-heavyoil2uc-recipe", order="c",
		energy_required = 5,
		ingredients = {
			{type="fluid", name="heavy-oil", amount=100, }
		},
		results=
		{
			{"y-unicomp-a2", 1},	
		},
		enabled = "true",		
		icon = "__Yuoki__/graphics/icons/atomics/heavy-oil2uc.png",
		order = "m-refined-rare3",
		subgroup = "y-atomics-f",
		category = "yuoki-atomics-recipe",
	},
	{
		type = "recipe",		
		name = "y-lubricant2uc-recipe", order="c",
		energy_required = 5,
		ingredients = {
			{type="fluid", name="lubricant", amount=95, }
		},
		results=
		{
			{"y-unicomp-a2", 1},	
		},
		enabled = "true",		
		icon = "__Yuoki__/graphics/icons/atomics/lubricant2uc.png",
		order = "m-refined-rare3",
		subgroup = "y-atomics-f",
		category = "yuoki-atomics-recipe",
	},
	{
		type = "recipe",		
		name = "y-petroleum-recipe", order="c",
		energy_required = 5,
		ingredients = {
			{type="fluid", name="petroleum-gas", amount=100, }
		},
		results=
		{
			{"y-unicomp-a2", 1},	
		},
		enabled = "true",		
		icon = "__Yuoki__/graphics/icons/atomics/petro2uc.png",
		order = "m-refined-rare3",
		subgroup = "y-atomics-f",
		category = "yuoki-atomics-recipe",
	},
	-- only reverse to crude-oil
	{
		type = "recipe",		
		name = "y-uc2crudeoil-recipe", order="c",
		energy_required = 5,
		ingredients = {
			{"y-unicomp-a2", 1},						
		},
		results=
		{
			{type="fluid", name="crude-oil", amount=100, }
		},
		enabled = "true",		
		icon = "__Yuoki__/graphics/icons/atomics/uc2crudeoil.png",
		order = "m-refined-rare3",
		subgroup = "y-atomics-r",
		category = "yuoki-atomics-recipe",
	},
	
	
	-- full fluid transition
	{
		type = "recipe",		
		name = "y-uc2liquid-recipe", order="c",
		energy_required = 5,
		ingredients = {
			{"y-unicomp-a2", 20},						
		},
		results=
		{
			{type="fluid", name="y-liquid-uc2", amount=10, }
		},
		enabled = "true",		
		icon = "__Yuoki__/graphics/icons/liquid_a2.png",
		order = "m-refined-rare3",
		subgroup = "y-atomics-f",
		category = "yuoki-atomics-recipe",
	},
	-- and fluid reverse
	{
		type = "recipe",		
		name = "y-liquid2uc-recipe", order="c",
		energy_required = 5,
		ingredients = {
			{type="fluid", name="y-liquid-uc2", amount=10, }
			
		},
		results=
		{
			{"y-unicomp-a2", 20},						
		},
		enabled = "true",		
		icon = "__Yuoki__/graphics/icons/unicomp_stack.png",
		order = "m-refined-rare3",
		subgroup = "y-atomics-r",
		category = "yuoki-atomics-recipe",
	},
				
})

==> Yuoki_0.5.71.zip: Yuoki_0.5.71/prototypes/item/ir_atomics.lua <==
data:extend(
{
	-- pure atomic constructs
	{
		type = "recipe",
		name = "y-ac-iron2uc-recipe", order="a",
		energy_required = 2.0,
		enabled = "true",
		ingredients = {{"iron-ore", 20},}, 
		result = "y-unicomp-a2",
		result_count = 1,
		subgroup = "y-atomics-f", 
		category = "yuoki-atomics-recipe",
		icon = "__Yuoki__/graphics/icons/atomics/iron2uc.png",
	},		
	{
		type = "recipe",
		name = "y-ac-copper2uc-recipe", order="a",	
		energy_required = 2.0,
		enabled = "true",
		ingredients = {{"copper-ore", 20},}, 
		result = "y-unicomp-a2",
		result_count = 1,
		subgroup = "y-atomics-f",
		category = "yuoki-atomics-recipe",
		icon = "__Yuoki__/graphics/icons/atomics/copper2uc.png",
	},		
	{
		type = "recipe",
		name = "y-ac-wood2uc-recipe", order="a",
		energy_required = 2.0,
		enabled = "true",
		ingredients = {{"raw-wood", 20},}, 
		result = "y-unicomp-a2",
		result_count = 1,
		subgroup = "y-atomics-f",
		category = "yuoki-atomics-recipe",
		icon = "__Yuoki__/graphics/icons/atomics/wood2uc.png",
	},		
	{
		type = "recipe",
		name = "y-ac-stone2uc-recipe", order="a",
		energy_required = 2.0,
		enabled = "true",
		ingredients = {{"stone", 20},}, 
		result = "y-unicomp-a2",
		result_count = 1,
		subgroup = "y-atomics-f",
		category = "yuoki-atomics-recipe",
		icon = "__Yuoki__/graphics/icons/atomics/stone2uc.png",
	},		
	{
		type = "recipe",
		name = "y-ac-coal2uc-recipe", order="a",
		energy_required = 2.0,
		enabled = "true",
		ingredients = {{"coal", 20},}, 
		result = "y-unicomp-a2",
		result_count = 1,
		subgroup = "y-atomics-f",
		category = "yuoki-atomics-recipe",
		icon = "__Yuoki__/graphics/icons/atomics/coal2uc.png",
	},		
	{
		type = "recipe",
		name = "y-ac-uc42uc-recipe", order="a",
		energy_required = 2.0,
		enabled = "true",
		ingredients = {{"y-res1", 10},}, 
		result = "y-unicomp-a2",
		result_count = 1,
		subgroup = "y-atomics-f",
		category = "yuoki-atomics-recipe",
		icon = "__Yuoki__/graphics/icons/atomics/n42uc.png",
	},			
	{
		type = "recipe",
		name = "y-ac-fuel2uc-recipe", order="a",
		energy_required = 2.0,
		enabled = "true",
		ingredients = {{"y-res2", 10},}, 
		result = "y-unicomp-a2",
		result_count = 1,
		subgroup = "y-atomics-f",
		category = "yuoki-atomics-recipe",
		icon = "__Yuoki__/graphics/icons/atomics/fuel2uc.png",
	},		
	{
		type = "recipe",
		name = "y-ac-slag2uc-recipe", order="a",
		energy_required = 2.0,
		enabled = "true",
		ingredients = {{"y-slag", 100},}, 
		result = "y-unicomp-a2",
		result_count = 1,
		subgroup = "y-atomics-f",
		category = "yuoki-atomics-recipe",
		icon = "__Yuoki__/graphics/icons/atomics/slag2uc.png",
	},		
	{
		type = "recipe",
		name = "y-ac-crystal2uc-recipe", order="a",
		energy_required = 2.0,
		enabled = "true",
		ingredients = {{"y-crystal2", 100},}, 
		result = "y-unicomp-a2",
		result_count = 1,
		subgroup = "y-atomics-f",
		category = "yuoki-atomics-recipe",
		icon = "__Yuoki__/graphics/icons/atomics/crystal2uc.png",
	},			

	{
		type = "recipe",
		name = "y_ac_uran2uc_recipe", order="a",
		energy_required = 4.0,
		enabled = "true",
		ingredients = {{"uranium-ore", 12},}, 
		result = "y-unicomp-a2",
		result_count = 1,
		subgroup = "y-atomics-f",
		category = "yuoki-atomics-recipe",
		icon = "__Yuoki__/graphics/icons/atomics/uranium2uc.png",
	},			

	
	--[[
	{
		type = "recipe",
		name = "y-battery-rip1-recipe",				
		energy_required = 1.0,
		enabled = "true",
		ingredients = {{"y-battery-single-use1", 10},}, 
		result = "y-unicomp-a2",
		result_count = 1,
		category = "yuoki-atomics-recipe",
		subgroup = "y-atomics-f",
	},	
	{
		type = "recipe",
		name = "y-battery-rip2-recipe",				
		energy_required = 1.0,
		enabled = "true",
		ingredients = {{"y-unicomp-a2", 1},}, 
		result = "battery",
		result_count = 5,
		category = "yuoki-atomics-recipe",
		subgroup = "y-atomics-r",
	},	
	{
		type = "recipe",
		name = "y_alien_artis2_recipe",				
		energy_required = 1.0,
		enabled = "true",
		ingredients = {{"y-unicomp-a2", 1},}, 
		result = "alien-artifact",
		result_count = 3,
		category = "yuoki-atomics-recipe",
		subgroup = "y-atomics-r",
	},	

	
	
	
	{
		type = "recipe",
		name = "y_alien_artis1_recipe",				
		energy_required = 1.0,
		enabled = "true",
		ingredients = {{"alien-artifact", 3},}, 
		result = "y-unicomp-a2",
		result_count = 1,
		category = "yuoki-atomics-recipe",
		subgroup = "y-atomics-f",
	},	
	
	]]
	
	
	-- changed to formpress 214-1226 and to smelts 215-0103
	--[[
	{
		type = "recipe",
		name = "y-ac-richdust2uc-recipe", order="a",
		energy_required = 2.0,
		enabled = "true",
		ingredients = {{"y-richdust", 20},}, 
		result = "y-unicomp-a2",
		result_count = 1,
		subgroup = "y-ore",
		category = "yuoki-formpress-recipe",	
		--category = "yuoki-atomics-recipe",
		icon = "__Yuoki__/graphics/icons/richdust.png",
	},
	]]

	-- toxic-dust-recycle
	{
		type = "recipe",
		name = "y-ac-toxic2uc-recipe", order="a",
		energy_required = 2.0,
		enabled = "true",
		ingredients = {{"y-toxic-dust", 70},}, 
		result = "y-unicomp-a2",
		result_count = 1,
		subgroup = "y-atomics-f",
		category = "yuoki-atomics-recipe",
		icon = "__Yuoki__/graphics/icons/toxic-dust_recycle.png",
	},		
	-- mud-ball-recycle
	{
		type = "recipe",
		name = "y-ac-mud2uc-recipe", order="a",
		energy_required = 2.0,
		enabled = "true",
		ingredients = {{"y-dry_mud", 30},}, 
		result = "y-unicomp-a2",
		result_count = 1,
		subgroup = "y-atomics-f",
		category = "yuoki-atomics-recipe",
		icon = "__Yuoki__/graphics/icons/mud_recycle.png",
	},		
	
	
	-- reverse atomic transfers and ++
	{
		type = "recipe",
		name = "y-ac-uc2copper-recipe", order="b",
		energy_required = 2.0,
		enabled = "true",
		ingredients = {{"y-unicomp-a2", 1},}, 
		result = "copper-ore",
		result_count = 20,
		subgroup = "y-atomics-r",
		category = "yuoki-atomics-recipe",
		icon = "__Yuoki__/graphics/icons/atomics/uc2copper.png",
	},		
	{
		type = "recipe",
		name = "y-ac-uc2iron-recipe", order="b",
		energy_required = 2.0,
		enabled = "true",
		ingredients = {{"y-unicomp-a2", 1},}, 
		result = "iron-ore",
		result_count = 20,
		subgroup = "y-atomics-r",
		category = "yuoki-atomics-recipe",
		icon = "__Yuoki__/graphics/icons/atomics/uc2iron.png",
	},		
	{
		type = "recipe",
		name = "y-ac-uc2wood-recipe", order="a",
		energy_required = 2.0,
		enabled = "true",
		ingredients = {{"y-unicomp-a2", 1},}, 
		result = "raw-wood",
		result_count = 20,
		subgroup = "y-atomics-r",
		category = "yuoki-atomics-recipe",
		icon = "__Yuoki__/graphics/icons/atomics/uc2wood.png",
	},		
	{
		type = "recipe",
		name = "y-ac-uc2coal-recipe", order="b",
		energy_required = 2.0,
		enabled = "true",
		ingredients = {{"y-unicomp-a2", 1},}, 
		result = "coal",
		result_count = 20,
		subgroup = "y-atomics-r",
		category = "yuoki-atomics-recipe",
		icon = "__Yuoki__/graphics/icons/atomics/uc2coal.png",
	},		
	{
		type = "recipe",
		name = "y-ac-uc2stone-recipe", order="b",
		energy_required = 2.0,
		enabled = "true",
		ingredients = {{"y-unicomp-a2", 1},}, 
		result = "stone",
		result_count = 20,
		subgroup = "y-atomics-r",
		category = "yuoki-atomics-recipe",
		icon = "__Yuoki__/graphics/icons/atomics/uc2stone.png",
	},		
	{
		type = "recipe",
		name = "y-ac-uc2uc4-recipe", order="b",
		energy_required = 2.0,
		enabled = "true",
		ingredients = {{"y-unicomp-a2", 1},}, 
		result = "y-res1",
		result_count = 10,
		subgroup = "y-atomics-r",
		category = "yuoki-atomics-recipe",
		icon = "__Yuoki__/graphics/icons/atomics/uc2n4.png",
	},		
	{
		type = "recipe",
		name = "y-ac-uc2fuel-recipe", order="b",
		energy_required = 2.0,
		enabled = "true",
		ingredients = {{"y-unicomp-a2", 1},}, 
		result = "y-res2",
		result_count = 10,
		subgroup = "y-atomics-r",
		category = "yuoki-atomics-recipe",
		icon = "__Yuoki__/graphics/icons/atomics/uc2fuel.png",
	},		

	{
		type = "recipe",
		name = "y-ac-uc2plastic-recipe", order="b",
		energy_required = 2.0,
		enabled = "true",
		ingredients = {{"y-unicomp-a2", 1},}, 
		result = "plastic-bar",
		result_count = 8,
		subgroup = "y-atomics-r",
		category = "yuoki-atomics-recipe",
		icon = "__Yuoki__/graphics/icons/atomics/uc2plastic.png",
	},		

	{
		type = "recipe",
		name = "y_ac_uc2uranore_recipe", order="b",
		energy_required = 4.0,
		enabled = "true",
		ingredients = {{"y-unicomp-a2", 1},}, 
		result = "uranium-ore",
		result_count = 12,
		subgroup = "y-atomics-r",
		category = "yuoki-atomics-recipe",
		icon = "__Yuoki__/graphics/icons/atomics/uc2uranium.png",
	},		


	
	--[[
	{
		type = "recipe",
		name = "y-ac-uc2sulfur-recipe", order="b",
		energy_required = 2.0,
		enabled = "true",
		ingredients = {{"y-unicomp-a2", 1},}, 
		result = "sulfur",
		result_count = 6,
		subgroup = "y-atomics-r",
		category = "yuoki-atomics-recipe",
		--icon = "__Yuoki__/graphics/icons/atomics/uc2plastic.png",
	},		
	]]
	
	-- fluid transition
	{
		type = "recipe",		
		name = "y-lightoil2uc-recipe", order="c",
		energy_required = 5,
		ingredients = {
			{type="fluid", name="light-oil", amount=100, }
		},
		results=
		{
			{"y-unicomp-a2", 1},	
		},
		enabled = "true",		
		icon = "__Yuoki__/graphics/icons/atomics/lightoil2uc.png",
		order = "m-refined-rare3",
		subgroup = "y-atomics-f",
		category = "yuoki-atomics-recipe",
	},
	{
		type = "recipe",		
		name = "y-heavyoil2uc-recipe", order="c",
		energy_required = 5,
		ingredients = {
			{type="fluid", name="heavy-oil", amount=100, }
		},
		results=
		{
			{"y-unicomp-a2", 1},	
		},
		enabled = "true",		
		icon = "__Yuoki__/graphics/icons/atomics/heavy-oil2uc.png",
		order = "m-refined-rare3",
		subgroup = "y-atomics-f",
		category = "yuoki-atomics-recipe",
	},
	{
		type = "recipe",		
		name = "y-lubricant2uc-recipe", order="c",
		energy_required = 5,
		ingredients = {
			{type="fluid", name="lubricant", amount=95, }
		},
		results=
		{
			{"y-unicomp-a2", 1},	
		},
		enabled = "true",		
		icon = "__Yuoki__/graphics/icons/atomics/lubricant2uc.png",
		order = "m-refined-rare3",
		subgroup = "y-atomics-f",
		category = "yuoki-atomics-recipe",
	},
	{
		type = "recipe",		
		name = "y-petroleum-recipe", order="c",
		energy_required = 5,
		ingredients = {
			{type="fluid", name="petroleum-gas", amount=100, }
		},
		results=
		{
			{"y-unicomp-a2", 1},	
		},
		enabled = "true",		
		icon = "__Yuoki__/graphics/icons/atomics/petro2uc.png",
		order = "m-refined-rare3",
		subgroup = "y-atomics-f",
		category = "yuoki-atomics-recipe",
	},
	-- only reverse to crude-oil
	{
		type = "recipe",		
		name = "y-uc2crudeoil-recipe", order="c",
		energy_required = 5,
		ingredients = {
			{"y-unicomp-a2", 1},						
		},
		results=
		{
			{type="fluid", name="crude-oil", amount=100, }
		},
		enabled = "true",		
		icon = "__Yuoki__/graphics/icons/atomics/uc2crudeoil.png",
		order = "m-refined-rare3",
		subgroup = "y-atomics-r",
		category = "yuoki-atomics-recipe",
	},
	
	
	-- full fluid transition
	{
		type = "recipe",		
		name = "y-uc2liquid-recipe", order="c",
		energy_required = 5,
		ingredients = {
			{"y-unicomp-a2", 20},						
		},
		results=
		{
			{type="fluid", name="y-liquid-uc2", amount=10, }
		},
		enabled = "true",		
		icon = "__Yuoki__/graphics/icons/liquid_a2.png",
		order = "m-refined-rare3",
		subgroup = "y-atomics-f",
		category = "yuoki-atomics-recipe",
	},
	-- and fluid reverse
	{
		type = "recipe",		
		name = "y-liquid2uc-recipe", order="c",
		energy_required = 5,
		ingredients = {
			{type="fluid", name="y-liquid-uc2", amount=10, }
			
		},
		results=
		{
			{"y-unicomp-a2", 20},						
		},
		enabled = "true",		
		icon = "__Yuoki__/graphics/icons/unicomp_stack.png",
		order = "m-refined-rare3",
		subgroup = "y-atomics-r",
		category = "yuoki-atomics-recipe",
	},
				
})
